@@ -96,7 +96,7 @@ class Domoticz(IPlugin):
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
 #				log.msg("resp  :  %s" % (req))				
 				log.msg("resp  :  %s" % (resp))
-				log.msg("response   :  %s" % (resp.json())			
+				log.msg("response   :  %s" % (resp.json()))		
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
